#!/usr/bin/env ipython3

import math
import numpy as np
import matplotlib.pyplot as plt
from matplotlib.patches import Rectangle
import matplotlib.colors as mcolors
from IPython import get_ipython
get_ipython().run_line_magic('matplotlib', 'qt')

def clamp(value, min_value, max_value):
    return max(min_value, min(max_value, value))

def saturate(value):
    return clamp(value, 0.0, 1.0)

def hue_to_rgb(h):
    r = abs(h * 6.0 - 3.0) - 1.0
    g = 2.0 - abs(h * 6.0 - 2.0)
    b = 2.0 - abs(h * 6.0 - 4.0)
    return saturate(r), saturate(g), saturate(b)

def hsl_to_rgb(h, s, l):
    r, g, b = hue_to_rgb(h)
    c = (1.0 - abs(2.0 * l - 1.0)) * s
    r = (r - 0.5) * c + l
    g = (g - 0.5) * c + l
    b = (b - 0.5) * c + l
    return r, g, b

print('Team ID\tNameplate color\tScoreboard color')
teamcolor = []; scorecolor = []
for TeamNumber in range(64):
    r, g, b = hsl_to_rgb(TeamNumber / 64.0, 1, 0.75)
    nameplate_color = (int(r * 255), int(g * 255), int(b * 255))
    teamcolor.append((r,g,b))
    r, g, b = hsl_to_rgb(TeamNumber / 64.0, 1, 0.5)
    scoreboard_color = (int(r * 255), int(g * 255), int(b * 255), 127)
    scorecolor.append((r,g,b))
    print(f"{TeamNumber}\t{nameplate_color}\t{scoreboard_color}")

sort_colors = True
colors = mcolors.BASE_COLORS
title = "DDNet team colors"
emptycols = 0

cell_width = 212
cell_height = 22
swatch_width = 48
margin = 12
topmargin = 40

n = 63
ncols = 4 - emptycols
nrows = n // ncols + int(n % ncols > 0)

width = cell_width * 4 + 2 * margin
height = cell_height * nrows + margin + topmargin
dpi = 72

fig, ax = plt.subplots(figsize=(width / dpi, height / dpi), dpi=dpi)
fig.subplots_adjust(margin/width, margin/height,
		    (width-margin)/width, (height-topmargin)/height)
ax.set_xlim(0, cell_width * 4)
ax.set_ylim(cell_height * (nrows-0.5), -cell_height/2.)
ax.yaxis.set_visible(False)
ax.xaxis.set_visible(False)
ax.set_axis_off()
ax.set_title(title, fontsize=24, loc="left", pad=10)

##for i, name in enumerate(names):
for i in range(64):
    row = i % nrows
    col = i // nrows
    y = row * cell_height

    swatch_start_x = cell_width * col
    text_pos_x = cell_width * col + swatch_width + 7

    ax.add_patch(
	Rectangle(xy=(swatch_start_x, y-9), width=swatch_width,
		  height=18, facecolor=teamcolor[i])
    )

    ax.add_patch(
        Rectangle(xy=(swatch_start_x+swatch_width+7, y-9), width=swatch_width,
                  height=18, facecolor=scorecolor[i])
    )

    ax.text(swatch_start_x+2*swatch_width+14, y, str(i), fontsize=14,
	    horizontalalignment='left',
	    verticalalignment='center')



plt.show()
